@@ -1,8 +1,8 @@
-use agb_image_converter::{convert_image, Colour, ImageConverterConfig, TileSize};
-
 fn main() {
     println!("cargo:rerun-if-changed=crt0.s");
+    println!("cargo:rerun-if-changed=gba_mb.ld");
     println!("cargo:rerun-if-changed=interrupt_simple.s");
+    println!("cargo:rerun-if-changed=src/sound/mixer/mixer.s");
     println!("cargo:rerun-if-changed=gfx/test_logo.png");
 
     let out_file_name = "crt0.o";
@@ -11,7 +11,7 @@ fn main() {
 
     let out = std::process::Command::new("arm-none-eabi-as")
         .arg("-mthumb-interwork")
-        .arg("-mthumb")
+        .arg("-mcpu=arm7tdmi")
         .arg("-g")
         .args(&["-o", out_file_path.as_str()])
         .arg("crt0.s")
@@ -23,14 +23,4 @@ fn main() {
     }
 
     println!("cargo:rustc-link-search={}", out_dir);
-
-    convert_image(
-        ImageConverterConfig::builder()
-            .transparent_colour(Colour::from_rgb(1, 1, 1))
-            .tile_size(TileSize::Tile8)
-            .input_image("gfx/test_logo.png".into())
-            .output_file(format!("{}/test_logo.rs", out_dir).into())
-            .crate_prefix("crate".to_owned())
-            .build(),
-    );
 }
